pub enum PrincipalPhase {
NewMoon,
FirstQuarter,
FullMoon,
LastQuarter,
}Expand description
The four principal phases of the Moon.
Variants
NewMoon
🌑 The Moon appears completely dark.
FirstQuarter
🌓 The Moon is half visible after the new moon and before the full moon.
FullMoon
🌕 The Moon is fully visible.
LastQuarter
🌗 The Moon is half visible after the full moon and before the new moon.
Implementations
Sourceimpl PrincipalPhase
impl PrincipalPhase
Sourcepub fn as_emoji(self) -> char
pub fn as_emoji(self) -> char
Returns the Unicode emoji representation of the moon phase.
assert_eq!(PrincipalPhase::FullMoon.as_emoji(), '🌕');Sourcepub fn iter() -> Iter<'static, PrincipalPhase>
pub fn iter() -> Iter<'static, PrincipalPhase>
Views the four principal moon phases as an iterator.
assert_eq!(PrincipalPhase::iter().next(), Some(&PrincipalPhase::NewMoon));
assert_eq!(PrincipalPhase::iter().len(), 4);Trait Implementations
Sourceimpl Clone for PrincipalPhase
impl Clone for PrincipalPhase
Sourcefn clone(&self) -> PrincipalPhase
fn clone(&self) -> PrincipalPhase
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PrincipalPhase
Sourceimpl Debug for PrincipalPhase
impl Debug for PrincipalPhase
impl Eq for PrincipalPhase
Sourceimpl From<PrincipalPhase> for Phase
impl From<PrincipalPhase> for Phase
Sourcefn from(phase: PrincipalPhase) -> Phase
fn from(phase: PrincipalPhase) -> Phase
Converts to this type from the input type.
Sourceimpl Hash for PrincipalPhase
impl Hash for PrincipalPhase
Sourceimpl PartialEq for PrincipalPhase
impl PartialEq for PrincipalPhase
Sourcefn eq(&self, other: &PrincipalPhase) -> bool
fn eq(&self, other: &PrincipalPhase) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PrincipalPhase